summaryrefslogtreecommitdiffstats
path: root/generic
diff options
context:
space:
mode:
Diffstat (limited to 'generic')
-rw-r--r--generic/tclInterp.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/generic/tclInterp.c b/generic/tclInterp.c
index a42c339..781e5b5 100644
--- a/generic/tclInterp.c
+++ b/generic/tclInterp.c
@@ -10,7 +10,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclInterp.c,v 1.77 2007/09/06 18:13:20 dgp Exp $
+ * RCS: @(#) $Id: tclInterp.c,v 1.78 2007/09/06 19:23:56 dgp Exp $
*/
#include "tclInt.h"
@@ -338,11 +338,11 @@ Tcl_Init(
* will be set as the value of tcl_library.
*
* Note that this entire search mechanism can be bypassed by defining an
* alternate tclInit function before calling Tcl_Init().
*/
return Tcl_Eval(interp,
-"if {[info proc tclInit]==\"\"} {\n"
+"if {[namespace which -command tclInit] eq \"\"} {\n"
" proc tclInit {} {\n"
" global tcl_libPath tcl_library env tclDefaultLibrary\n"
" rename tclInit {}\n"
@@ -338,11 +338,11 @@ Tcl_Init(
*
* Note that this entire search mechanism can be bypassed by defining an
- * alternate tclInit function before calling Tcl_Init().
+ * alternate tclInit command before calling Tcl_Init().
*/
return Tcl_Eval(interp,